tests Package
=============

:mod:`tests` Package
--------------------

.. automodule:: permission.tests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`compatibility` Module
---------------------------

.. automodule:: permission.tests.compatibility
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`models` Module
--------------------

.. automodule:: permission.tests.models
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_handlers` Module
---------------------------

.. automodule:: permission.tests.test_handlers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: permission.tests.utils
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    permission.tests.test_logics
    permission.tests.test_templatetags
    permission.tests.test_utils

